OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Marcadores",
    "No file provided for import" : "No se especificó un archivo para importar",
    "Unsupported file type for import" : "Tipo de archivo no soportado para importar",
    "Details" : "Detalles",
    "Rename" : "Renombrar",
    "Copy link" : "Copiar liga",
    "Move" : "Mover",
    "Select all" : "Seleccionar todo",
    "Go back" : "Regresar",
    "New" : "Nuevo",
    "New folder" : "Carpeta nueva",
    "Search" : "Buscar",
    "Add a bookmark" : "Agregar un marcador",
    "Choose folder" : "Seleccioanr carpeta",
    "Submit" : "Enviar",
    "Cancel" : "Cancelar",
    "Recent" : "Reciente",
    "Shared with you" : "Compartido con usted",
    "Files" : "Archivos",
    "Delete" : "Borrar",
    "Settings" : "Configuraciones ",
    "Bookmarklet" : "Marcador a código ",
    "Need help?" : "¿Necesitas ayuda?",
    "Title" : "Título",
    "Link" : "Liga",
    "Tags" : "Etiquetas",
    "Notes" : "Notas",
    "Download file" : "Descargar archivo",
    "Owner" : "Dueño",
    "Sharing" : "Compartiendo",
    "Share link" : "Compartir liga",
    "Allow editing" : "Permitir edición",
    "Allow resharing" : "Permitir volver a compartir",
    "Privacy" : "Privacidad",
    "This URL is already bookmarked! Overwrite?" : "¡Esta URL ya está marcada! ¿Quieres sobreescribirlo?",
    "Folder" : "Carpeta",
    "Save" : "Guardar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
